<?php

namespace Pinpoint\Feefo\Cron;

/**
 * Class Reviews
 * @package Pinpoint\Feefo\Cron
 */
class Reviews {

    /**
     * @var \Psr\Log\LoggerInterface
     */
    protected $_logger;

    /**
     * @var \Evoluted\Feefo\Feefo
     */
    protected $feefoApi;

    /**
     * @var \Pinpoint\Feefo\Helper\Data
     */
    protected $feefoHelper;

    /**
     * @var \Pinpoint\Feefo\Model\FeefoReview
     */
    protected $feefoReview;

    /**
     * @var \Pinpoint\Feefo\Model\FeefoServiceReview
     */
    protected $feefoServiceReview;

    /**
     * @var string
     */
    const API_KEY_CONFIG_PATH = 'pinpoint_feefo/account_details/api_key';

    /**
     * Reviews constructor.
     * @param \Psr\Log\LoggerInterface $logger
     * @param \Pinpoint\Feefo\Helper\Data $feefoHelper
     * @param \Pinpoint\Feefo\Model\FeefoReview $feefoReview
     * @param \Pinpoint\Feefo\Model\FeefoServiceReview $feefoServiceReview
     */
    public function __construct(
        \Psr\Log\LoggerInterface $logger,
        \Pinpoint\Feefo\Helper\Data $feefoHelper,
        \Pinpoint\Feefo\Model\FeefoReview $feefoReview,
        \Pinpoint\Feefo\Model\FeefoServiceReview $feefoServiceReview
    ) {
        $this->_logger = $logger;
        $this->feefoHelper = $feefoHelper;
        $this->feefoReview = $feefoReview;
        $this->feefoServiceReview = $feefoServiceReview;

        $this->feefoApi = new \Evoluted\Feefo\Feefo(
          $this->feefoHelper->getConfig(\Pinpoint\Feefo\Model\Feed\Sales\Feed::MERCHANT_IDENTIFIER_CONFIG_PATH),
          $this->feefoHelper->getConfig(self::API_KEY_CONFIG_PATH)
        );
    }

    /**
     * @return $this
     */
    public function execute() {
        $this->_logger->info("--- Starting Feefo daily review poll ---");

        $this->getProductReviews();
        $this->getServiceReviews();

        return $this;
    }

    /**
     * @return void
     */
    protected function getProductReviews()
    {
        $lastReview = $this->feefoReview->getCollection()->getLastItem();
        $skipFirst = $lastReview ? true : false;

        $newReviews = $this->feefoApi->get('10/reviews/product', [
            'merchant_identifier' => $this->feefoApi->merchantIdentifier,
            'id>' => $lastReview->getData('feefo_rating_id')
        ]);

        $reviews = array_reverse($newReviews->reviews);
        foreach ($reviews as $review) {
            foreach ($review->products as $product) {
                if ($skipFirst) {
                    $skipFirst = false;
                    continue;
                }

                $feefoReview = $this->feefoReview;
                $feefoReview->setData([
                    'feefo_rating_id' => $product->id,
                    'customer_name' => $review->customer->display_name,
                    'product_sku' => $product->product->sku,
                    'rating' => (int)$product->rating->rating,
                    'product_title' => $product->product->title,
                    'summary' => $product->review,
                    'helpful_votes' => $product->helpful_votes,
                    'created_at' => $product->created_at
                ]);
                $feefoReview->save();

                $this->_logger->info(sprintf("Found review for: %s. Saving...", $product->product->sku));
            }
        }
    }

    /**
     * @return void
     */
    protected function getServiceReviews()
    {
        $lastReview = $this->feefoServiceReview->getCollection()->getLastItem();
        $skipFirst = $lastReview ? true : false;

        $newReviews = $this->feefoApi->get('10/reviews/service', [
            'merchant_identifier' => $this->feefoApi->merchantIdentifier,
            'id>' => $lastReview->getData('feefo_rating_id')
        ]);

        $reviews = array_reverse($newReviews->reviews);
        foreach ($reviews as $review) {
            if ($skipFirst) {
                $skipFirst = false;
                continue;
            }

            $feefoServiceReview = $this->feefoServiceReview;
            $feefoServiceReview->setData([
                'feefo_rating_id' => $review->service->id,
                'customer_name' => $review->customer->display_name,
                'rating' => (int)$review->service->rating->rating,
                'review_title' => $review->service->title,
                'summary' => $review->service->review,
                'helpful_votes' => $review->service->helpful_votes,
                'created_at' => $review->service->created_at
            ]);
            $feefoServiceReview->save();

            $this->_logger->info("Found service review. Saving...");
        }
    }
}