<?php

namespace Pinpoint\Feefo\Helper;

use Magento\Framework\App\Helper\AbstractHelper;
use Magento\Framework\UrlInterface;

/**
 * Class Data
 * @package Pinpoint\Feefo\Helper
 */
class Data extends AbstractHelper
{
    /**
     * @var \Magento\Framework\Filesystem\DirectoryList
     */
    protected $directoryList;

    /**
     * @var \Magento\Framework\View\Asset\Repository
     */
    protected $assetRepo;

    /**
     * @var string
     */
    const CUSTOM_FEEFO_LOGO_CONFIG_PATH = 'pinpoint_feefo/module_settings/custom_feefo_image';

    /**
     * Data constructor.
     * @param \Magento\Framework\Filesystem\DirectoryList $directoryList
     * @param \Magento\Framework\View\Asset\Repository $assetRepo
     * @param \Magento\Framework\App\Helper\Context $context
     */
    public function __construct(
        \Magento\Framework\Filesystem\DirectoryList $directoryList,
        \Magento\Framework\View\Asset\Repository $assetRepo,
        \Magento\Framework\App\Helper\Context $context
    ) {
        $this->directoryList = $directoryList;
        $this->assetRepo = $assetRepo;

        parent::__construct($context);
    }

    /**
     * @param $path
     * @return mixed
     */
    public function getConfig($path) {
        return $this->scopeConfig->getValue($path, \Magento\Store\Model\ScopeInterface::SCOPE_STORE);
    }

    /**
     * @return null|string
     */
    public function getRequestIp()
    {
        $ip = null;
        if (!empty($_SERVER['HTTP_CLIENT_IP'])) {
            $ip = $_SERVER['HTTP_CLIENT_IP'];
        } elseif (!empty($_SERVER['HTTP_X_FORWARDED_FOR'])) {
            $ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
        } else {
            $ip = $_SERVER['REMOTE_ADDR'];
        }

        return $ip;
    }

    /**
     * @return string
     */
    public function getLogoUrl()
    {
        if ($customLogo = $this->getConfig(self::CUSTOM_FEEFO_LOGO_CONFIG_PATH)) {
            return
                $this->_urlBuilder->getBaseUrl(['_type' => UrlInterface::URL_TYPE_MEDIA])
                . DIRECTORY_SEPARATOR
                . 'pinpoint_feefo'
                . DIRECTORY_SEPARATOR
                . $customLogo
            ;
        }

        return $this->assetRepo->getUrl('Pinpoint_Feefo::images/default-feefo2.png');
    }

    /**
     * @param $starRating
     * @param string $selectId
     * @return string
     */
    public function getStarHtml($starRating, $selectId = 'feefo-star-rating')
    {
        $options = '';

        for ($i = 0; $i < 6; $i++) {
            $options .= sprintf('<option value="%s">%1$s</option>', $i);
        }

        return sprintf("<select id='%s' data-star-rating='%s'>%s</select>", $selectId, $starRating, $options);
    }

}