<?php

namespace Pinpoint\Feefo\Setup;

use Magento\Framework\Setup\ModuleDataSetupInterface;
use Magento\Eav\Setup\EavSetup;
use Magento\Eav\Setup\EavSetupFactory;
use Magento\Quote\Setup\QuoteSetupFactory;
use Magento\Sales\Setup\SalesSetupFactory;

/**
 * Class UpgradeData
 * @package Pinpoint\Feefo\Setup
 */
class UpgradeData extends \Pinpoint\Feefo\Model\Pinpoint\PinpointUpgrade
{
    /**
     * @var EavSetupFactory
     */
    protected $eavSetupFactory;

    /**
     * @var QuoteSetupFactory
     */
    protected $quoteSetupFactory;

    /**
     * @var SalesSetupFactory
     */
    protected $salesSetupFactory;

    /**
     * UpgradeData constructor.
     * @param EavSetupFactory $eavSetupFactory
     * @param QuoteSetupFactory $quoteSetupFactory
     * @param SalesSetupFactory $salesSetupFactory
     * @param \Magento\Framework\Module\Dir\Reader $moduleReader
     * @param \Magento\Framework\Xml\Parser $reader
     */
    public function __construct(
        EavSetupFactory $eavSetupFactory,
        QuoteSetupFactory $quoteSetupFactory,
        SalesSetupFactory $salesSetupFactory,
        \Magento\Framework\Module\Dir\Reader $moduleReader,
        \Magento\Framework\Xml\Parser $reader
    ) {
        $this->eavSetupFactory = $eavSetupFactory;
        $this->quoteSetupFactory = $quoteSetupFactory;
        $this->salesSetupFactory = $salesSetupFactory;

        parent::__construct($moduleReader, $reader);
    }


    /**
     * @param ModuleDataSetupInterface $setup
     */
    protected function upgrade_0_0_2(ModuleDataSetupInterface $setup)
    {
        /** @var EavSetup $eavSetup */
        $eavSetup = $this->eavSetupFactory->create(['setup' => $setup]);

        if (!$eavSetup->getAttributeId(\Magento\Catalog\Model\Product::ENTITY, 'pinpoint_gtin')) {
            $eavSetup->addAttribute(
                \Magento\Catalog\Model\Product::ENTITY,
                'pinpoint_gtin',
                [
                    'type' => 'varchar',
                    'label' => 'The Global Trade Item Number (GTIN)',
                    'input' => 'text',
                    'required' => false,
                    'sort_order' => 3,
                    'global' => \Magento\Eav\Model\Entity\Attribute\ScopedAttributeInterface::SCOPE_GLOBAL,
                    'group' => 'Feefo Additional Fields',
                    'used_in_product_listing' => true,
                    'visible_on_front' => false,
                    'visible' => true,
                    'user_defined' => false,
                    'default' => '',
                    'searchable' => false,
                    'filterable' => false,
                    'comparable' => false,
                    'unique' => false
                ]
            );
        }
    }

    /**
     * @param ModuleDataSetupInterface $setup
     */
    protected function upgrade_0_0_3(ModuleDataSetupInterface $setup)
    {
        /** @var EavSetup $eavSetup */
        $eavSetup = $this->eavSetupFactory->create(['setup' => $setup]);

        if (!$eavSetup->getAttributeId(\Magento\Catalog\Model\Product::ENTITY, 'pinpoint_mpn')) {
            $eavSetup->addAttribute(
                \Magento\Catalog\Model\Product::ENTITY,
                'pinpoint_mpn',
                [
                    'type' => 'varchar',
                    'label' => 'The Manufacturer Part Number (MPN)',
                    'input' => 'text',
                    'required' => false,
                    'sort_order' => 3,
                    'global' => \Magento\Eav\Model\Entity\Attribute\ScopedAttributeInterface::SCOPE_GLOBAL,
                    'group' => 'Feefo Additional Fields',
                    'used_in_product_listing' => true,
                    'visible_on_front' => false,
                    'visible' => true,
                    'user_defined' => false,
                    'default' => '',
                    'searchable' => false,
                    'filterable' => false,
                    'comparable' => false,
                    'unique' => false
                ]
            );
        }
    }

    /**
     * @param ModuleDataSetupInterface $setup
     */
    protected function upgrade_0_0_4(ModuleDataSetupInterface $setup)
    {
        /** @var \Magento\Quote\Setup\QuoteSetup $quoteInstaller */
        $quoteInstaller = $this->quoteSetupFactory->create(['resourceName' => 'quote_setup', 'setup' => $setup]);

        /** @var \Magento\Sales\Setup\SalesSetup $salesInstaller */
        $salesInstaller = $this->salesSetupFactory->create(['resourceName' => 'sales_setup', 'setup' => $setup]);

        $setup->startSetup();

        //Add attributes to quote
        $entityAttributesCodes = [
            'pinpoint_sales_channel' => 'varchar',
            'pinpoint_sales_person' => 'varchar'
        ];

        foreach ($entityAttributesCodes as $code => $type) {

            $attribute = ['type' => $type, 'length'=> 255, 'visible' => false, 'nullable' => true, 'default' => 'Web'];
            $quoteInstaller->addAttribute('quote', $code, $attribute);
            $salesInstaller->addAttribute('order', $code, $attribute);
            $salesInstaller->addAttribute('invoice', $code, $attribute);
        }

        $setup->endSetup();
    }

    /**
     * @param ModuleDataSetupInterface $setup
     */
    protected function upgrade_0_0_6(ModuleDataSetupInterface $setup)
    {
        /** @var EavSetup $eavSetup */
        $eavSetup = $this->eavSetupFactory->create(['setup' => $setup]);

        if (!$eavSetup->getAttributeId(\Magento\Catalog\Model\Product::ENTITY, 'pinpoint_exclude_feefo')) {
            $eavSetup->addAttribute(
                \Magento\Catalog\Model\Product::ENTITY,
                'pinpoint_exclude_feefo',
                [
                    'type' => 'int',
                    'label' => 'Include in Feefo reviews?',
                    'input' => 'select',
                    'required' => false,
                    'sort_order' => 3,
                    'source' => \Magento\Eav\Model\Entity\Attribute\Source\Boolean::class,
                    'global' => \Magento\Eav\Model\Entity\Attribute\ScopedAttributeInterface::SCOPE_GLOBAL,
                    'group' => 'Feefo Additional Fields',
                    'used_in_product_listing' => true,
                    'visible_on_front' => false,
                    'visible' => true,
                    'user_defined' => false,
                    'default' => '1',
                    'searchable' => false,
                    'filterable' => false,
                    'comparable' => false,
                    'unique' => false
                ]
            );
        }
    }
}