<?php

namespace Pinpoint\Feefo\Setup;

use Magento\Framework\DB\Ddl\Table;
use Magento\Framework\Setup\UpgradeSchemaInterface;
use Magento\Framework\Setup\ModuleContextInterface;
use Magento\Framework\Setup\SchemaSetupInterface;

/**
 * @codeCoverageIgnore
 */
class UpgradeSchema implements UpgradeSchemaInterface
{
    /**
     * {@inheritdoc}
     */
    public function upgrade(SchemaSetupInterface $setup, ModuleContextInterface $context)
    {
        $setup->startSetup();

        if (version_compare($context->getVersion(), '0.0.5', '<')) {
             $this->createFeefoReviewTable($setup);
        }

        if (version_compare($context->getVersion(), '0.0.7', '<')) {
            $this->createFeefoServiceReviewTable($setup);
        }

        $setup->endSetup();
    }


    /**
     * @param SchemaSetupInterface $setup
     */
    protected function createFeefoReviewTable(SchemaSetupInterface $setup)
    {
        $installer = $setup;
        $installer->startSetup();

        // Get tutorial_simplenews table
        $tableName = $installer->getTable('pinpoint_feefo_reviews');
        // Check if the table already exists
        if ($installer->getConnection()->isTableExists($tableName) != true) {
            // Create tutorial_simplenews table
            $table = $installer->getConnection()
                ->newTable($tableName)
                ->addColumn(
                    'id',
                    Table::TYPE_INTEGER,
                    null,
                    [
                        'identity' => true,
                        'unsigned' => true,
                        'nullable' => false,
                        'primary' => true
                    ],
                    'ID'
                )
                ->addColumn(
                    'feefo_rating_id',
                    Table::TYPE_TEXT,
                    null,
                    ['nullable' => false],
                    'Feefo Rating Id'
                )
                ->addColumn(
                    'customer_name',
                    Table::TYPE_TEXT,
                    null,
                    ['nullable' => false],
                    'Customer Name'
                )
                ->addColumn(
                    'product_sku',
                    Table::TYPE_TEXT,
                    null,
                    ['nullable' => false],
                    'Product Sku'
                )
                ->addColumn(
                    'rating',
                    Table::TYPE_INTEGER,
                    null,
                    ['nullable' => false],
                    'Rating'
                )
                ->addColumn(
                    'product_title',
                    Table::TYPE_TEXT,
                    null,
                    ['nullable' => false,],
                    'Product Title'
                )
                ->addColumn(
                    'summary',
                    Table::TYPE_TEXT,
                    null,
                    ['nullable' => false,],
                    'Review Summary'
                )
                ->addColumn(
                    'helpful_votes',
                    Table::TYPE_TEXT,
                    null,
                    ['nullable' => false,],
                    'Review Votes'
                )
                ->addColumn(
                    'created_at',
                    Table::TYPE_DATETIME,
                    null,
                    ['nullable' => false],
                    'Created At'
                )
                ->addColumn(
                    'status',
                    Table::TYPE_SMALLINT,
                    null,
                    ['nullable' => false, 'default' => 1],
                    'Status'
                )
                ->setComment('Pinpoint Feefo Reviews')
                ->setOption('type', 'InnoDB')
                ->setOption('charset', 'utf8');
            $installer->getConnection()->createTable($table);
        }

        $installer->endSetup();
    }

    /**
     * @param SchemaSetupInterface $setup
     */
    protected function createFeefoServiceReviewTable(SchemaSetupInterface $setup)
    {
        $installer = $setup;
        $installer->startSetup();

        // Get tutorial_simplenews table
        $tableName = $installer->getTable('pinpoint_feefo_service_reviews');
        // Check if the table already exists
        if ($installer->getConnection()->isTableExists($tableName) != true) {
            // Create tutorial_simplenews table
            $table = $installer->getConnection()
                ->newTable($tableName)
                ->addColumn(
                    'id',
                    Table::TYPE_INTEGER,
                    null,
                    [
                        'identity' => true,
                        'unsigned' => true,
                        'nullable' => false,
                        'primary' => true
                    ],
                    'ID'
                )
                ->addColumn(
                    'feefo_rating_id',
                    Table::TYPE_TEXT,
                    null,
                    ['nullable' => false],
                    'Feefo Rating Id'
                )
                ->addColumn(
                    'customer_name',
                    Table::TYPE_TEXT,
                    null,
                    ['nullable' => false],
                    'Customer Name'
                )
                ->addColumn(
                    'rating',
                    Table::TYPE_INTEGER,
                    null,
                    ['nullable' => false],
                    'Rating'
                )
                ->addColumn(
                    'review_title',
                    Table::TYPE_TEXT,
                    null,
                    ['nullable' => false,],
                    'Review Title'
                )
                ->addColumn(
                    'summary',
                    Table::TYPE_TEXT,
                    null,
                    ['nullable' => false,],
                    'Review Summary'
                )
                ->addColumn(
                    'helpful_votes',
                    Table::TYPE_TEXT,
                    null,
                    ['nullable' => false,],
                    'Review Votes'
                )
                ->addColumn(
                    'created_at',
                    Table::TYPE_DATETIME,
                    null,
                    ['nullable' => false],
                    'Created At'
                )
                ->addColumn(
                    'status',
                    Table::TYPE_SMALLINT,
                    null,
                    ['nullable' => false, 'default' => 1],
                    'Status'
                )
                ->setComment('Pinpoint Feefo Service Reviews')
                ->setOption('type', 'InnoDB')
                ->setOption('charset', 'utf8');
            $installer->getConnection()->createTable($table);
        }

        $installer->endSetup();
    }
}
